Crate sos_login

Crate sos_login 

Identity folder protects delegated passwords and is used to authenticate an account.

Modules

device
Types for device support.

Structs

FolderKeys
Collection of folder access keys.
Identity
Identity manages access to an identity vault and the private keys for a user.
IdentityFolder
Identity folder stores delegated passwords and an asymmetric encryption key.
PrivateIdentity
Private identity containing the in-memory identity vault and signing keys.
PublicIdentity
Public account identity information.

Enums

Error
Errors generated by the library.

Traits

DelegatedAccess
Delegated access to folder keys.

Type Aliases

UrnLookup
Cache of mapping between secret URN and secret identifiers so we can find identity vault secrets quickly.