Identity

Struct Identity 

pub struct Identity { /* private fields */ }
Identity manages access to an identity vault and the private keys for a user.

Implementations

Source

impl Identity

pub fn new(target: BackendTarget) -> Self

Create a new unauthenticated login identity.

pub fn devices(&self) -> Result<&DeviceManager, Error>

Device manager.

pub fn account(&self) -> Result<&PublicIdentity, Error>

Account information.

pub fn identity(&self) -> Result<&IdentityFolder, Error>

Private identity.

pub async fn verify(&self, key: &AccessKey) -> bool

Verify the access key for this account.

pub async fn rename_account( &mut self, account_name: String, ) -> Result<(), Error>

Rename this account by changing the name of the identity vault.

pub async fn create_file_encryption_password(&mut self) -> Result<(), Error>

Available on crate feature files only.

Create the file encryption password.

pub async fn find_file_encryption_password(&self) -> Result<SecretString, Error>

Available on crate feature files only.

Find the password used for symmetric file encryption (AGE).

pub async fn login( &mut self, account_id: &AccountId, key: &AccessKey, ) -> Result<(), Error>

Login to an identity folder.

pub async fn sign_in( &mut self, account_id: &AccountId, key: &AccessKey, ) -> Result<(), Error>

Sign in to a user account.

pub async fn sign_out(&mut self) -> Result<(), Error>

Sign out this user by locking the account identity vault.