pub struct Identity { /* private fields */ }Expand description
Identity manages access to an identity vault and the private keys for a user.
Implementations
Sourceimpl Identity
impl Identity
Sourcepub fn new(target: BackendTarget) -> Self
pub fn new(target: BackendTarget) -> Self
Create a new unauthenticated login identity.
Sourcepub fn devices(&self) -> Result<&DeviceManager, Error>
pub fn devices(&self) -> Result<&DeviceManager, Error>
Device manager.
Sourcepub fn account(&self) -> Result<&PublicIdentity, Error>
pub fn account(&self) -> Result<&PublicIdentity, Error>
Account information.
Sourcepub fn identity(&self) -> Result<&IdentityFolder, Error>
pub fn identity(&self) -> Result<&IdentityFolder, Error>
Private identity.
Sourcepub async fn rename_account(
&mut self,
account_name: String,
) -> Result<(), Error>
pub async fn rename_account( &mut self, account_name: String, ) -> Result<(), Error>
Rename this account by changing the name of the identity vault.
Sourcepub async fn create_file_encryption_password(&mut self) -> Result<(), Error>
Available on crate feature files only.
pub async fn create_file_encryption_password(&mut self) -> Result<(), Error>
files only.Create the file encryption password.
Sourcepub async fn find_file_encryption_password(&self) -> Result<SecretString, Error>
Available on crate feature files only.
pub async fn find_file_encryption_password(&self) -> Result<SecretString, Error>
files only.Find the password used for symmetric file encryption (AGE).
Sourcepub async fn login(
&mut self,
account_id: &AccountId,
key: &AccessKey,
) -> Result<(), Error>
pub async fn login( &mut self, account_id: &AccountId, key: &AccessKey, ) -> Result<(), Error>
Login to an identity folder.